@@ -3,12 +3,38 @@ from __future__ import print_function, unicode_literals
 import re
 
 from .statements import DOTS, ImportLeaf, ImportStatement
-from .utils import list_strip
+from .utils import list_strip, read
 
 
 CHARS = re.compile(r'[\\()]')
 
 
+def get_artifacts(path):
+    """
+    Get artifacts for the given file.
+
+    Parameters
+    ----------
+    path : str
+        Path to a file
+
+    Returns
+    -------
+    artifacts : dict
+        Dictionary of file artifacts which should be
+        considered while processing imports.
+    """
+    artifacts = {
+        'sep': '\n',
+    }
+
+    lines = read(path).splitlines(True)
+    if len(lines) > 1 and lines[0][-2:] == '\r\n':
+        artifacts['sep'] = '\r\n'
+
+    return artifacts
+
+
 def find_imports_from_lines(iterator):
     """
     Find import statements as strings from
@@ -102,15 +128,34 @@ def find_imports_from_lines(iterator):
         # strip each line
         line_imports = list_strip(line_imports)
 
-        # if line ended with "import\"
-        # that will result in incorrect join
-        # so explicitly add space after "import"
-        # note this has to be after stripping each line
-        line_imports = map(lambda i: (i if not i.endswith(' import')
-                                      else i + ' '),
-                           line_imports)
+        # handle line breaks which can cause
+        # incorrect syntax when recombined
+        # mostly these are cases when line break
+        # happens around either "import" or "as"
+        # e.g. from long.import.here \n import foo
+        # e.g. import package \n as foo
+        for word in ('import', 'as'):
+            kwargs = {
+                'startswith': {
+                    'word': word,
+                    'pre': '',
+                    'post': ' ',
+                },
+                'endswith': {
+                    'word': word,
+                    'pre': ' ',
+                    'post': '',
+                }
+            }
+            for f, k in kwargs.items():
+                line_imports = list(map(
+                    lambda i: (i if not getattr(i, f)('{pre}{word}{post}'
+                                                      ''.format(**k))
+                               else '{post}{i}{pre}'.format(i=i, **k)),
+                    line_imports
+                ))
 
-        import_line = ''.join(line_imports)
+        import_line = ''.join(line_imports).strip()
 
         # strip ending comma if there
         if import_line.endswith(','):
@@ -119,7 +164,7 @@ def find_imports_from_lines(iterator):
         yield import_line, line_numbers
 
 
-def parse_import_statement(stem, line_numbers):
+def parse_import_statement(stem, line_numbers, **kwargs):
     """
     Parse single import statement into ``ImportStatement`` instances.
 
@@ -167,10 +212,13 @@ def parse_import_statement(stem, line_numbers):
         if name == as_name:
             stem = name
 
-    return ImportStatement(line_numbers, stem, leafs)
+    return ImportStatement(line_numbers,
+                           stem,
+                           leafs,
+                           **kwargs)
 
 
-def parse_statements(iterable):
+def parse_statements(iterable, **kwargs):
     """
     Parse iterable into ``ImportStatement`` instances.
 
@@ -190,7 +238,9 @@ def parse_statements(iterable):
             stems = import_line.replace('import ', '').strip().split(',')
 
             for stem in stems:
-                yield parse_import_statement(stem.strip(), line_numbers)
+                yield parse_import_statement(stem.strip(),
+                                             line_numbers,
+                                             **kwargs)
 
         else:
             stem, leafs_string = list_strip(
@@ -199,4 +249,7 @@ def parse_statements(iterable):
             leafs = filter(None, list_strip(leafs_string.split(',')))
             leafs = list(map(ImportLeaf, leafs))
 
-            yield ImportStatement(line_numbers, stem, leafs)
+            yield ImportStatement(line_numbers,
+                                  stem,
+                                  leafs,
+                                  **kwargs)
